@@ -37,22 +37,16 @@ class ExtendedJsonEncoder(json.JSONEncoder):
         self.pandas_dynamic = None
 
         try:
-            logger.info("Searching for pandas module dynamically")
             self.pandas_dynamic = importlib.import_module('pandas')
-            logger.info("Found pandas module dynamically")
         except ImportError as err:
             #pandas not found, leave as null so it can be skipped below
-            logger.info("Did not find pandas")
             pass
 
         self.np_dynamic = None
         try:
-            logger.info("Searching for numpy module dynamically")
             self.np_dynamic = importlib.import_module('numpy')
-            logger.info("Found numpy module dynamically")
         except ImportError as err:
-            # pandas not found, leave as null so it can be skipped below
-            logger.info("Did not find numpy")
+            # numpy not found, leave as null so it can be skipped below
             pass
 
 
